@@ -29,7 +29,6 @@ from calibre.library.comments import merge_comments
 from calibre.utils.config import tweaks
 from calibre.utils.icu import sort_key
 from calibre.utils.localization import ngettext
-from polyglot.builtins import iteritems
 
 DATA_FILES_ICON_NAME = 'unpack-book.png'
 
@@ -383,7 +382,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
                     failed_ids |= d.rejected_ids
                     restrict_to_failed = True
                 nid_map = {}
-                for book_id, (changed, mi) in iteritems(d.accepted):
+                for book_id, (changed, mi) in d.accepted.items():
                     if mi is None:  # discarded
                         continue
                     if changed:
@@ -571,7 +570,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
 
     def books_dropped(self, merge_map):
         covers_replaced = False
-        for dest_id, src_ids in iteritems(merge_map):
+        for dest_id, src_ids in merge_map.items():
             if not self.confirm_large_merge(len(src_ids) + 1):
                 continue
             from calibre.gui2.dialogs.confirm_merge import merge_drop
@@ -725,7 +724,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
         if d.result() == QDialog.DialogCode.Accepted:
             to_rename = d.to_rename  # dict of new text to old ids
             to_delete = d.to_delete  # list of ids
-            for old_id, new_name in iteritems(to_rename):
+            for old_id, new_name in to_rename.items():
                 model.rename_collection(old_id, new_name=str(new_name))
             for item in to_delete:
                 model.delete_collection_using_id(item)
@@ -753,7 +752,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
         '''
         if title is None:
             title = _('Applying changed metadata')
-        self.apply_id_map = list(iteritems(id_map))
+        self.apply_id_map = list(id_map.items())
         self.apply_current_idx = 0
         self.apply_failures = []
         self.applied_ids = set()
