@@ -85,7 +85,6 @@ from calibre.utils.cleantext import clean_xml_chars
 from calibre.utils.config import tweaks
 from calibre.utils.filenames import make_long_path_useable
 from calibre.utils.imghdr import what
-from polyglot.builtins import iteritems, itervalues
 
 # Cleanup Qt markup {{{
 
@@ -121,7 +120,7 @@ def lift_styles(tag, style_map):
         if common_props is None:
             common_props = style.copy()
         else:
-            for k, v in tuple(iteritems(common_props)):
+            for k, v in tuple(common_props.items()):
                 if style.get(k) != v:
                     del common_props[k]
     if not has_text and common_props:
@@ -271,14 +270,14 @@ def cleanup_qt_markup(root):
                 s['margin-right'] = '0.5em'
             elif s == {'float': 'right'}:
                 s['margin-left'] = '0.5em'
-    for style in itervalues(style_map):
+    for style in style_map.values():
         filter_qt_styles(style)
         fw = style.get('font-weight')
         if fw in ('600', '700'):
             style['font-weight'] = 'bold'
-    for tag, style in iteritems(style_map):
+    for tag, style in style_map.items():
         if style:
-            tag.set('style', '; '.join(f'{k}: {v}' for k, v in iteritems(style)))
+            tag.set('style', '; '.join(f'{k}: {v}' for k, v in style.items()))
         else:
             tag.attrib.pop('style', None)
     for span in root.xpath('//span[not(@style)]'):
@@ -368,14 +367,17 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
         self._parent = weakref.ref(parent)
         self.shortcut_map = {}
 
-        def r(name, icon, text, checkable=False, shortcut=None):
-            ac = QAction(QIcon.ic(icon + '.png'), text, self)
+        def r(name, icon, text, checkable=False, shortcut=None, callback=None):
+            ac = QAction(QIcon.ic(icon + '.png'), text, self) if icon else QAction(text, self)
             ac.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
             if checkable:
                 ac.setCheckable(checkable)
             setattr(self, 'action_'+name, ac)
-            ac.triggered.connect(getattr(self, 'do_' + name))
+            callback = callback or getattr(self, 'do_' + name)
+            ac.triggered.connect(callback)
             if shortcut is not None:
+                if isinstance(shortcut, str):
+                    shortcut = QKeySequence(shortcut, QKeySequence.SequenceFormat.PortableText)
                 self.shortcut_map[shortcut] = ac
                 sc = shortcut if isinstance(shortcut, QKeySequence) else QKeySequence(shortcut)
                 ac.setShortcut(sc)
@@ -400,7 +402,7 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
         r('remove_format', 'edit-clear', _('Remove formatting'))
         r('copy', 'edit-copy', _('Copy'), shortcut=QKeySequence.StandardKey.Copy)
         r('paste', 'edit-paste', _('Paste'), shortcut=QKeySequence.StandardKey.Paste)
-        r('paste_and_match_style', 'edit-paste', _('Paste and match style'), shortcut=QKeySequence('ctrl+shift+v', QKeySequence.SequenceFormat.PortableText))
+        r('paste_and_match_style', 'edit-paste', _('Paste and match style'), shortcut='ctrl+shift+v')
         r('cut', 'edit-cut', _('Cut'), shortcut=QKeySequence.StandardKey.Cut)
         r('indent', 'format-indent-more', _('Increase indentation'))
         r('outdent', 'format-indent-less', _('Decrease indentation'))
@@ -409,10 +411,15 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
         r('color', 'format-text-color', _('Foreground color'))
         r('background', 'format-fill-color', _('Background color'))
         r('insert_link', 'insert-link', _('Insert link') if self.insert_images_separately else _('Insert link or image'),
-          shortcut=QKeySequence('Ctrl+l', QKeySequence.SequenceFormat.PortableText))
-        r('insert_image', 'view-image', _('Insert image'), shortcut=QKeySequence('Ctrl+p', QKeySequence.SequenceFormat.PortableText))
+          shortcut='Ctrl+l')
+        r('insert_image', 'view-image', _('Insert image'), shortcut='Ctrl+p')
         r('insert_hr', 'format-text-hr', _('Insert separator'),)
         r('clear', 'trash', _('Clear'))
+        r('upper_case', '', _('Upper case'), shortcut='Ctrl+alt+u', callback=self.upper_case)
+        r('lower_case', '', _('Lower case'), shortcut='Ctrl+alt+l', callback=self.lower_case)
+        r('capitalize', '', _('Capitalize'), shortcut='Ctrl+alt+c', callback=self.capitalize)
+        r('swap_case', '', _('Swap case'), shortcut='Ctrl+alt+s', callback=self.swap_case)
+        r('title_case', '', _('Title case'), shortcut='Ctrl+alt+t', callback=self.title_case)
 
         self.action_block_style = QAction(QIcon.ic('format-text-heading.png'),
                 _('Style text block'), self)
@@ -1178,7 +1185,12 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
         menu.addMenu(m)
 
         if st and st.strip():
-            self.create_change_case_menu(menu)
+            m = QMenu(_('Change case'), menu)
+            m.addAction(self.action_upper_case)
+            m.addAction(self.action_lower_case)
+            m.addAction(self.action_swap_case)
+            m.addAction(self.action_title_case)
+            m.addAction(self.action_capitalize)
         parent = self._parent()
         if hasattr(parent, 'toolbars_visible'):
             vis = parent.toolbars_visible
@@ -1195,6 +1207,117 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
         menu.addAction(_('Smarten punctuation'), parent.smarten_punctuation)
         menu.exec(ev.globalPos())
 
+    def modify_case_operation(self, func):
+        cursor: QTextCursor = self.textCursor()
+        if not cursor.hasSelection():
+            cursor.select(QTextCursor.SelectionType.Document)
+        start = cursor.selectionStart()
+        end = cursor.selectionEnd()
+        doc = self.document()
+
+        # Helper: collect blocks intersecting the selection
+        blocks = []
+
+        # Create a cursor at start to find the first block
+        sc = QTextCursor(doc)
+        sc.setPosition(start)
+        first_block = sc.block()
+
+        block = first_block
+        while block.isValid() and block.position() < end:
+            block_start = block.position()
+            block_len = block.length()  # includes block separator
+            block_end = block_start + block_len
+            seg_start = max(start, block_start)
+            seg_end = min(end, block_end)
+            if seg_start >= seg_end:
+                block = block.next()
+                continue
+
+            # record block-level formatting (block format and list format if any)
+            bf = QTextBlockFormat(block.blockFormat())
+            list_format = None
+            blist = block.textList()
+            if blist is not None:
+                list_format = QTextListFormat(blist.format())
+
+            # iterate fragments in the block and extract only the overlapped text pieces
+            fragments = []
+            fragment_text = ''
+            it = block.begin()
+            while not it.atEnd():
+                frag = it.fragment()
+                if frag.isValid():
+                    fpos = frag.position()
+                    flen = frag.length()
+                    fend = fpos + flen
+                    ov_start = max(seg_start, fpos)
+                    ov_end = min(seg_end, fend)
+                    if ov_start < ov_end:
+                        rel_start = ov_start - fpos
+                        rel_len = ov_end - ov_start
+                        text = frag.text()[rel_start:rel_start + rel_len]
+                        fmt = QTextCharFormat(frag.charFormat())
+                        fragments.append((len(fragment_text), len(text), fmt))
+                        fragment_text += text
+                it += 1
+
+            blocks.append({
+                'blockFormat': bf,
+                'listFormat': list_format,
+                'blockStart': block_start,
+                'fragments': fragments,
+                'fragment_text': fragment_text,
+            })
+
+            block = block.next()
+
+        if not blocks:
+            return
+
+        # Replace the selection preserving inline and block formats.
+        editcur = QTextCursor(doc)
+        editcur.setPosition(start)
+        editcur.setPosition(end, QTextCursor.MoveMode.KeepAnchor)
+
+        editcur.beginEditBlock()
+        editcur.removeSelectedText()
+        # after removal the cursor is at `start`
+        editcur.setPosition(start)
+
+        # Insert blocks and fragments. Handle first block specially to avoid unwanted new block
+        for idx, blk in enumerate(blocks):
+            blk_fmt = blk['blockFormat']
+            list_fmt = blk['listFormat']
+
+            # Determine if original first block was partial (selection started mid-block).
+            if idx == 0:
+                # keep and reuse the current block — apply its block format/list
+                editcur.setBlockFormat(blk_fmt)
+            else:
+                # subsequent blocks -> always insert a new block with the original format
+                editcur.insertBlock(blk_fmt)
+            if list_fmt is not None:
+                editcur.createList(list_fmt)
+
+            fragment_text = func(blk['fragment_text'])
+            # insert the fragments for this block, preserving char formats
+            for start_pos, length, ch_fmt in blk['fragments']:
+                if start_pos >= len(fragment_text):
+                    break
+                # Convert selected fragment text
+                # (paragraph separators are not part of per-fragment text here)
+                editcur.insertText(fragment_text[start_pos:start_pos+length], ch_fmt)
+
+        editcur.endEditBlock()
+
+        # Reselect the replaced text so selection remains
+        new_end = editcur.position()
+        new_cursor = self.textCursor()
+        new_cursor.setPosition(start)
+        new_cursor.setPosition(new_end, QTextCursor.MoveMode.KeepAnchor)
+        self.setTextCursor(new_cursor)
+
 # }}}
 
 
